@@ -20,6 +20,7 @@ from nowcasting_dataset.dataset.batch import Batch
 from nowcasting_dataloader.subset import subselect_data
 from nowcasting_dataset.filesystem.utils import download_to_local, delete_all_files_in_temp_path
 from nowcasting_dataset.utils import set_fsspec_for_multiprocess
+from nowcasting_dataloader.utils.position_encoding import generate_position_encodings_for_batch
 
 logger = logging.getLogger(__name__)
 
@@ -87,7 +88,8 @@ class NetCDFDataset(torch.utils.data.Dataset):
         required_keys: Union[Tuple[str], List[str]] = None,
         history_minutes: Optional[int] = None,
         forecast_minutes: Optional[int] = None,
-        normalize: bool = False
+        normalize: bool = False,
+        add_position_encoding: bool = False,
     ):
         """
         Netcdf Dataset
@@ -105,6 +107,7 @@ class NetCDFDataset(torch.utils.data.Dataset):
             configuration: configuration object
             cloud: which cloud is used, can be "gcp", "aws" or "local".
             normalize: normalize the batch data
+            add_position_encoding: Whether to add position encoding or not
         """
         self.n_batches = n_batches
         self.src_path = src_path
@@ -114,24 +117,27 @@ class NetCDFDataset(torch.utils.data.Dataset):
         self.forecast_minutes = forecast_minutes
         self.configuration = configuration
         self.normalize = normalize
+        self.add_position_encoding = add_position_encoding
 
         logger.info(f"Setting up NetCDFDataset for {src_path}")
 
         if self.forecast_minutes is None:
-            self.forecast_minutes = configuration.process.forecast_minutes
+            self.forecast_minutes = configuration.input_data.default_forecast_minutes
         if self.history_minutes is None:
-            self.history_minutes = configuration.process.history_minutes
+            self.history_minutes = configuration.input_data.default_history_minutes
 
         # see if we need to select the subset of data. If turned on -
         # only history_minutes + current time + forecast_minutes data is used.
         self.select_subset_data = False
-        if self.forecast_minutes != configuration.process.forecast_minutes:
+        if self.forecast_minutes != configuration.input_data.default_forecast_minutes:
             self.select_subset_data = True
-        if self.history_minutes != configuration.process.history_minutes:
+        if self.history_minutes != configuration.input_data.default_history_minutes:
             self.select_subset_data = True
 
         # Index into either sat_datetime_index or nwp_target_time indicating the current time,
-        self.current_timestep_5_index = int(configuration.process.history_minutes // 5) + 1
+        self.current_timestep_5_index = (
+            int(configuration.input_data.default_history_minutes // 5) + 1
+        )
 
         if required_keys is None:
             required_keys = DEFAULT_REQUIRED_KEYS
@@ -184,7 +190,7 @@ class NetCDFDataset(torch.utils.data.Dataset):
         else:
             local_netcdf_folder = self.src_path
 
-        batch = Batch.load_netcdf(local_netcdf_folder, batch_idx=batch_idx)
+        batch: Batch = Batch.load_netcdf(local_netcdf_folder, batch_idx=batch_idx)
 
         if self.select_subset_data:
             batch = subselect_data(
@@ -193,8 +199,8 @@ class NetCDFDataset(torch.utils.data.Dataset):
                 forecast_minutes=self.forecast_minutes,
                 current_timestep_index=self.current_timestep_5_index,
             )
-
-        # TODO Add positional encodings here https://github.com/openclimatefix/nowcasting_dataloader/issues/4
+        if self.add_position_encoding:
+            position_encodings = generate_position_encodings_for_batch(batch)
         # change batch into ML learning batch ready for training
         batch: BatchML = BatchML.from_batch(batch=batch)
 
@@ -207,7 +213,11 @@ class NetCDFDataset(torch.utils.data.Dataset):
         if self.normalize:
             batch.normalize()
 
-        return batch.dict()
+        batch: dict = batch.dict()
+        if self.add_position_encoding:
+            # Add position encodings
+            batch.update(position_encodings)
+        return batch
 
 
 def worker_init_fn(worker_id):
